# ABLInfer

ABLInfer is a Python library and command-line tool based on [DeepInfer](http://www.deepinfer.org>) for dispatching medical images to segmentation and registration toolkits, primarily aimed at using Docker containers for automated, deep-learning based segmentation.

The full documentation is built regularly and may be found on [ReadTheDocs](https://ablinfer.readthedocs.io/en/latest/).
